package com.example.myapplication

import android.content.Intent
import android.os.Bundle
import android.widget.ImageButton
import androidx.appcompat.app.AppCompatActivity
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.google.android.material.floatingactionbutton.FloatingActionButton

class MainActivity : AppCompatActivity() {
    private val recipes = mutableListOf<Recipe>() // Rezeptliste

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        // Theme basierend auf Einstellungen setzen
        val preferences = getSharedPreferences("appSettings", MODE_PRIVATE)
        val savedColorOption = preferences.getInt("colorOption", 1)
        setTheme(if (savedColorOption == 1) R.style.Theme_myapplication else R.style.Theme_MyApp_BlueTheme)

        setContentView(R.layout.activity_main)

        // RecyclerView und FloatingActionButton initialisieren
        val recyclerView = findViewById<RecyclerView>(R.id.recipeRecyclerView)
        val addButton = findViewById<FloatingActionButton>(R.id.addRecipeButton)

        // Dummy-Rezepte hinzufügen
        recipes.addAll(
            listOf(
                Recipe("Tomatensuppe", "Tomaten, Salz, Pfeffer", "Tomaten kochen und würzen", listOf("Tomaten klein schneiden", "Mit Wasser in einem Topf kochen", "Mit Salz und Pfeffer würzen"), "android.resource://com.example.myapplication/drawable/tomatensuppe"),
                Recipe("Spaghetti Bolognese", "Spaghetti, Hackfleisch, Tomatensoße", "Spaghetti kochen und Hackfleisch anbraten", listOf("Spaghetti in Salzwasser kochen", "Hackfleisch in einer Pfanne anbraten", "Tomatensauce hinzufügen und würzen"), "android.resource://com.example.myapplication/drawable/spaghetti"),
                Recipe("Pancakes", "Mehl, Milch, Eier", "Alles verrühren und braten", listOf("Alle Zutaten in einer Schüssel verrühren", "In einer Pfanne Butter schmelzen", "Teig in die Pfanne gießen und 5 min ausbacken"), "android.resource://com.example.myapplication/drawable/pancakes")
            )
        )

        recyclerView.layoutManager = LinearLayoutManager(this)
        recyclerView.adapter = RecipeAdapter(recipes) { recipe ->
            val intent = Intent(this, RecipeDetailActivity::class.java)
            intent.putExtra("RECIPE", recipe)
            startActivity(intent)
        }

        addButton.setOnClickListener {
            AddRecipeDialogFragment { newRecipe ->
                recipes.add(newRecipe)
                recyclerView.adapter?.notifyItemInserted(recipes.size - 1)
            }.show(supportFragmentManager, "AddRecipeDialogFragment")
        }

        findViewById<ImageButton>(R.id.settingsButton).setOnClickListener {
            startActivity(Intent(this, SettingsActivity::class.java))
        }
    }
}